@@ -46,5 +46,15 @@
    typedef int64_t i64_t;
 #endif
 
+#ifndef __HAVE_UINT_T
+   #define __HAVE_UINT_T
+   typedef unsigned int uint;
+#endif
+
+#ifndef __HAVE_ULONG_T
+   #define __HAVE_ULONG_T
+   typedef unsigned long ulong;
+#endif
+
 
 #endif /* DEF_TYPES_H */
