@@ -2,16 +2,16 @@
 #define GUI_LOG_H 1
 
 /* guilog.h v0.2
-   Copyright: Tomasz Pawlak (C) 2014-2019
-   License:   GPLv3
+   Copyright: Tomasz Pawlak (C) 2014-2024
+   License:   GPLv3+
 */
 
 #include <wx/log.h>
 #include <wx/frame.h>
-#include "returncode/rcode.h"
+#include "rcode/rcode.h"
 
 enum {
-   msg_buf_sz = 4096
+   msg_buf_sz = 1024
 };
 
 class guilog_cl {
@@ -23,8 +23,6 @@ class guilog_cl {
       wxString     slog;
       char         rcd_msg_buff[msg_buf_sz];
 
-      const rcd_scope_t* psc_wxedid;
-
       inline bool isReady() {return (status>0);};
 
       void RcodeToString(rcode retU, wxString& str);
@@ -41,9 +39,7 @@ class guilog_cl {
 
    guilog_cl();
 
-   ~guilog_cl();
+   ~guilog_cl() {};
 };
 
-extern guilog_cl guilog;
-
 #endif /* GUI_LOG_H */
